pub struct CodexBootstrapFile { /* private fields */ }Expand description
Opaque owner-only bootstrap file. Its path and contents are intentionally absent from Debug/serde/browser-safe records and the file is deleted on drop or rotation.